• | the quality system regulation, which imposes FDA current Good Manufacturing Practice (“cGMP”) requirements governing the methods used in, and the facilities and controls used for, the design, manufacture, packaging, servicing, labeling, storage, installation, and distribution of all finished medical devices intended for human use;
• | labeling regulations, including a prohibition on product promotion for unapproved or“off label”uses;
• | the medical device reporting regulation requiring a manufacturer to report to the FDA if its device may have caused or contributed to a death or serious injury or malfunctioned in a way that would likely cause or contribute to a death or serious injury if it were to recur; and
• | the reports of corrections and removals regulation, which requires a manufacturer to report recalls and field actions to the FDA if initiated to reduce a risk to health posed by the device or to remedy a violation of the FDCA that may present a risk to health.